@@ -111,7 +111,16 @@ class Venue():
             except:
                 pass
 
-
+    def reload(self):
+        """Reload the Venue, by touching its ini file"""
+        try:
+            with file(self.UWSGI_INI, 'a'):
+                os.utime(self.UWSGI_INI, None)
+        except IOError:
+            print 'Could not update, permission denied.'
+            return
+        self.get_uwsgi_port()
+        return
 
 
 
